<?php
// Own namespace
namespace CoreFramework\Manager;

// Import framework stuff
use CoreFramework\Generic\FrameworkInterface;
use CoreFramework\Template\CompileableTemplate;

/**
 * An interface for managing applications. This can be a lot. E.g.:
 *
 * - Un-/locking applications
 * - Creating selectors for the selector-mode
 * - Usage statistics
 * - And many more...
 *
 * @author		Roland Haeder <webmaster@shipsimu.org>
 * @version		0.0.0
 * @copyright	Copyright (c) 2007, 2008 Roland Haeder, 2009 - 2017 Core Developer Team
 * @license		GNU GPL 3.0 or any newer version
 * @link		http://www.shipsimu.org
 *
 * This program is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program. If not, see <http://www.gnu.org/licenses/>.
 */
interface ManageableApplication extends FrameworkInterface {
	/**
	 * 1) Setups application data
	 *
	 * @return	void
	 */
	function setupApplicationData ();

	/**
	 * 2) Does initial stuff before starting the application
	 *
	 * @return	void
	 */
	function initApplication ();

	/**
	 * 3) Launches the application
	 *
	 * @return	void
	 */
	function launchApplication ();

	/**
	 * Handle the indexed array of fatal messages and puts them out in an
	 * acceptable fasion
	 *
	 * @param	$messageList	An array of fatal messages
	 * @return	void
	 */
	function handleFatalMessages (array $messageList);

	/**
	 * Builds the master template's name
	 *
	 * @return	$masterTemplateName		Name of the master template
	 */
	function buildMasterTemplateName();

	/**
	 * Assigns extra application-depending data
	 *
	 * @param	$templateInstance	An instance of a CompileableTemplate
	 * @return	void
	 * @todo	Nothing to add?
	 */
	function assignExtraTemplateData (CompileableTemplate $templateInstance);

}
